@@ -1,5 +1,8 @@
 #pragma once
 
+#include <utility>
+#include <vector>
+
 #include "esphome/core/component.h"
 #include "esphome/components/light/light_state.h"
 #include "esphome/components/light/addressable_light.h"
@@ -34,13 +37,10 @@ class AddressableLightEffect : public LightEffect {
     this->start();
   }
   void stop() override { this->get_addressable_()->set_effect_active(false); }
-  virtual void apply(AddressableLight &it, const ESPColor &current_color) = 0;
+  virtual void apply(AddressableLight &it, const Color &current_color) = 0;
   void apply() override {
-    LightColorValues color = this->state_->remote_values;
-    // not using any color correction etc. that will be handled by the addressable layer
-    ESPColor current_color =
-        ESPColor(static_cast<uint8_t>(color.get_red() * 255), static_cast<uint8_t>(color.get_green() * 255),
-                 static_cast<uint8_t>(color.get_blue() * 255), static_cast<uint8_t>(color.get_white() * 255));
+    // not using any color correction etc. that will be handled by the addressable layer through ESPColorCorrection
+    Color current_color = color_from_light_color_values(this->state_->remote_values);
     this->apply(*this->get_addressable_(), current_color);
   }
 
@@ -50,27 +50,32 @@ class AddressableLightEffect : public LightEffect {
 
 class AddressableLambdaLightEffect : public AddressableLightEffect {
  public:
-  AddressableLambdaLightEffect(const std::string &name, const std::function<void(AddressableLight &, ESPColor)> &f,
+  AddressableLambdaLightEffect(const std::string &name,
+                               std::function<void(AddressableLight &, Color, bool initial_run)> f,
                                uint32_t update_interval)
-      : AddressableLightEffect(name), f_(f), update_interval_(update_interval) {}
-  void apply(AddressableLight &it, const ESPColor &current_color) override {
+      : AddressableLightEffect(name), f_(std::move(f)), update_interval_(update_interval) {}
+  void start() override { this->initial_run_ = true; }
+  void apply(AddressableLight &it, const Color &current_color) override {
     const uint32_t now = millis();
     if (now - this->last_run_ >= this->update_interval_) {
       this->last_run_ = now;
-      this->f_(it, current_color);
+      this->f_(it, current_color, this->initial_run_);
+      this->initial_run_ = false;
+      it.schedule_show();
     }
   }
 
  protected:
-  std::function<void(AddressableLight &, ESPColor)> f_;
+  std::function<void(AddressableLight &, Color, bool initial_run)> f_;
   uint32_t update_interval_;
   uint32_t last_run_{0};
+  bool initial_run_;
 };
 
 class AddressableRainbowLightEffect : public AddressableLightEffect {
  public:
   explicit AddressableRainbowLightEffect(const std::string &name) : AddressableLightEffect(name) {}
-  void apply(AddressableLight &it, const ESPColor &current_color) override {
+  void apply(AddressableLight &it, const Color &current_color) override {
     ESPHSVColor hsv;
     hsv.value = 255;
     hsv.saturation = 240;
@@ -81,6 +86,7 @@ class AddressableRainbowLightEffect : public AddressableLightEffect {
       var = hsv;
       hue += add;
     }
+    it.schedule_show();
   }
   void set_speed(uint32_t speed) { this->speed_ = speed; }
   void set_width(uint16_t width) { this->width_ = width; }
@@ -102,7 +108,7 @@ class AddressableColorWipeEffect : public AddressableLightEffect {
   void set_colors(const std::vector<AddressableColorWipeEffectColor> &colors) { this->colors_ = colors; }
   void set_add_led_interval(uint32_t add_led_interval) { this->add_led_interval_ = add_led_interval; }
   void set_reverse(bool reverse) { this->reverse_ = reverse; }
-  void apply(AddressableLight &it, const ESPColor &current_color) override {
+  void apply(AddressableLight &it, const Color &current_color) override {
     const uint32_t now = millis();
     if (now - this->last_add_ < this->add_led_interval_)
       return;
@@ -112,7 +118,7 @@ class AddressableColorWipeEffect : public AddressableLightEffect {
     else
       it.shift_right(1);
     const AddressableColorWipeEffectColor color = this->colors_[this->at_color_];
-    const ESPColor esp_color = ESPColor(color.r, color.g, color.b, color.w);
+    const Color esp_color = Color(color.r, color.g, color.b, color.w);
     if (this->reverse_)
       it[-1] = esp_color;
     else
@@ -122,12 +128,13 @@ class AddressableColorWipeEffect : public AddressableLightEffect {
       this->at_color_ = (this->at_color_ + 1) % this->colors_.size();
       AddressableColorWipeEffectColor &new_color = this->colors_[this->at_color_];
       if (new_color.random) {
-        ESPColor c = ESPColor::random_color();
+        Color c = Color::random_color();
         new_color.r = c.r;
         new_color.g = c.g;
         new_color.b = c.b;
       }
     }
+    it.schedule_show();
   }
 
  protected:
@@ -144,40 +151,42 @@ class AddressableScanEffect : public AddressableLightEffect {
   explicit AddressableScanEffect(const std::string &name) : AddressableLightEffect(name) {}
   void set_move_interval(uint32_t move_interval) { this->move_interval_ = move_interval; }
   void set_scan_width(uint32_t scan_width) { this->scan_width_ = scan_width; }
-  void apply(AddressableLight &it, const ESPColor &current_color) override {
-    it.all() = ESPColor::BLACK;
+  void apply(AddressableLight &it, const Color &current_color) override {
+    const uint32_t now = millis();
+    if (now - this->last_move_ < this->move_interval_)
+      return;
 
-    for (auto i = 0; i < this->scan_width_; i++) {
+    if (direction_) {
+      this->at_led_++;
+      if (this->at_led_ == it.size() - this->scan_width_)
+        this->direction_ = false;
+    } else {
+      this->at_led_--;
+      if (this->at_led_ == 0)
+        this->direction_ = true;
+    }
+    this->last_move_ = now;
+
+    it.all() = Color::BLACK;
+    for (uint32_t i = 0; i < this->scan_width_; i++) {
       it[this->at_led_ + i] = current_color;
     }
 
-    const uint32_t now = millis();
-    if (now - this->last_move_ > this->move_interval_) {
-      if (direction_) {
-        this->at_led_++;
-        if (this->at_led_ == it.size() - this->scan_width_)
-          this->direction_ = false;
-      } else {
-        this->at_led_--;
-        if (this->at_led_ == 0)
-          this->direction_ = true;
-      }
-      this->last_move_ = now;
-    }
+    it.schedule_show();
   }
 
  protected:
   uint32_t move_interval_{};
   uint32_t scan_width_{1};
   uint32_t last_move_{0};
-  int at_led_{0};
+  uint32_t at_led_{0};
   bool direction_{true};
 };
 
 class AddressableTwinkleEffect : public AddressableLightEffect {
  public:
   explicit AddressableTwinkleEffect(const std::string &name) : AddressableLightEffect(name) {}
-  void apply(AddressableLight &addressable, const ESPColor &current_color) override {
+  void apply(AddressableLight &addressable, const Color &current_color) override {
     const uint32_t now = millis();
     uint8_t pos_add = 0;
     if (now - this->last_progress_ > this->progress_interval_) {
@@ -195,7 +204,7 @@ class AddressableTwinkleEffect : public AddressableLightEffect {
         else
           view.set_effect_data(new_pos);
       } else {
-        view = ESPColor::BLACK;
+        view = Color::BLACK;
       }
     }
     while (random_float() < this->twinkle_probability_) {
@@ -204,6 +213,7 @@ class AddressableTwinkleEffect : public AddressableLightEffect {
         continue;
       addressable[pos].set_effect_data(1);
     }
+    addressable.schedule_show();
   }
   void set_twinkle_probability(float twinkle_probability) { this->twinkle_probability_ = twinkle_probability; }
   void set_progress_interval(uint32_t progress_interval) { this->progress_interval_ = progress_interval; }
@@ -217,7 +227,7 @@ class AddressableTwinkleEffect : public AddressableLightEffect {
 class AddressableRandomTwinkleEffect : public AddressableLightEffect {
  public:
   explicit AddressableRandomTwinkleEffect(const std::string &name) : AddressableLightEffect(name) {}
-  void apply(AddressableLight &it, const ESPColor &current_color) override {
+  void apply(AddressableLight &it, const Color &current_color) override {
     const uint32_t now = millis();
     uint8_t pos_add = 0;
     if (now - this->last_progress_ > this->progress_interval_) {
@@ -233,7 +243,7 @@ class AddressableRandomTwinkleEffect : public AddressableLightEffect {
         if (color == 0) {
           view = current_color * sine;
         } else {
-          view = ESPColor(((color >> 2) & 1) * sine, ((color >> 1) & 1) * sine, ((color >> 0) & 1) * sine);
+          view = Color(((color >> 2) & 1) * sine, ((color >> 1) & 1) * sine, ((color >> 0) & 1) * sine);
         }
         const uint8_t new_x = x + pos_add;
         if (new_x > 0b11111)
@@ -241,7 +251,7 @@ class AddressableRandomTwinkleEffect : public AddressableLightEffect {
         else
           view.set_effect_data((new_x << 3) | color);
       } else {
-        view = ESPColor(0, 0, 0, 0);
+        view = Color(0, 0, 0, 0);
       }
     }
     while (random_float() < this->twinkle_probability_) {
@@ -251,6 +261,7 @@ class AddressableRandomTwinkleEffect : public AddressableLightEffect {
       const uint8_t color = random_uint32() & 0b111;
       it[pos].set_effect_data(0b1000 | color);
     }
+    it.schedule_show();
   }
   void set_twinkle_probability(float twinkle_probability) { this->twinkle_probability_ = twinkle_probability; }
   void set_progress_interval(uint32_t progress_interval) { this->progress_interval_ = progress_interval; }
@@ -266,9 +277,9 @@ class AddressableFireworksEffect : public AddressableLightEffect {
   explicit AddressableFireworksEffect(const std::string &name) : AddressableLightEffect(name) {}
   void start() override {
     auto &it = *this->get_addressable_();
-    it.all() = ESPColor::BLACK;
+    it.all() = Color::BLACK;
   }
-  void apply(AddressableLight &it, const ESPColor &current_color) override {
+  void apply(AddressableLight &it, const Color &current_color) override {
     const uint32_t now = millis();
     if (now - this->last_update_ < this->update_interval_)
       return;
@@ -276,7 +287,7 @@ class AddressableFireworksEffect : public AddressableLightEffect {
     // "invert" the fade out parameter so that higher values make fade out faster
     const uint8_t fade_out_mult = 255u - this->fade_out_rate_;
     for (auto view : it) {
-      ESPColor target = view.get() * fade_out_mult;
+      Color target = view.get() * fade_out_mult;
       if (target.r < 64)
         target *= 170;
       view = target;
@@ -290,11 +301,12 @@ class AddressableFireworksEffect : public AddressableLightEffect {
     if (random_float() < this->spark_probability_) {
       const size_t pos = random_uint32() % it.size();
       if (this->use_random_color_) {
-        it[pos] = ESPColor::random_color();
+        it[pos] = Color::random_color();
       } else {
         it[pos] = current_color;
       }
     }
+    it.schedule_show();
   }
   void set_update_interval(uint32_t update_interval) { this->update_interval_ = update_interval; }
   void set_spark_probability(float spark_probability) { this->spark_probability_ = spark_probability; }
@@ -312,7 +324,7 @@ class AddressableFireworksEffect : public AddressableLightEffect {
 class AddressableFlickerEffect : public AddressableLightEffect {
  public:
   explicit AddressableFlickerEffect(const std::string &name) : AddressableLightEffect(name) {}
-  void apply(AddressableLight &it, const ESPColor &current_color) override {
+  void apply(AddressableLight &it, const Color &current_color) override {
     const uint32_t now = millis();
     const uint8_t intensity = this->intensity_;
     const uint8_t inv_intensity = 255 - intensity;
@@ -320,18 +332,20 @@ class AddressableFlickerEffect : public AddressableLightEffect {
       return;
 
     this->last_update_ = now;
-    fast_random_set_seed(random_uint32());
+    uint32_t rng_state = random_uint32();
     for (auto var : it) {
-      const uint8_t flicker = fast_random_8() % intensity;
+      rng_state = (rng_state * 0x9E3779B9) + 0x9E37;
+      const uint8_t flicker = (rng_state & 0xFF) % intensity;
       // scale down by random factor
       var = var.get() * (255 - flicker);
 
       // slowly fade back to "real" value
       var = (var.get() * inv_intensity) + (current_color * intensity);
     }
+    it.schedule_show();
   }
   void set_update_interval(uint32_t update_interval) { this->update_interval_ = update_interval; }
-  void set_intensity(float intensity) { this->intensity_ = static_cast<uint8_t>(roundf(intensity * 255.0f)); }
+  void set_intensity(float intensity) { this->intensity_ = to_uint8_scale(intensity); }
 
  protected:
   uint32_t update_interval_{16};
