@@ -25,6 +25,7 @@ CONF_CURRENT_TEMPERATURE_MULTIPLIER = "current_temperature_multiplier"
 CONF_TARGET_TEMPERATURE_MULTIPLIER = "target_temperature_multiplier"
 CONF_ECO_DATAPOINT = "eco_datapoint"
 CONF_ECO_TEMPERATURE = "eco_temperature"
+CONF_REPORTS_FAHRENHEIT = "reports_fahrenheit"
 
 TuyaClimate = tuya_ns.class_("TuyaClimate", climate.Climate, cg.Component)
 
@@ -110,6 +111,7 @@ CONFIG_SCHEMA = cv.All(
             cv.Optional(CONF_TARGET_TEMPERATURE_MULTIPLIER): cv.positive_float,
             cv.Optional(CONF_ECO_DATAPOINT): cv.uint8_t,
             cv.Optional(CONF_ECO_TEMPERATURE): cv.temperature,
+            cv.Optional(CONF_REPORTS_FAHRENHEIT, default=False): cv.boolean,
         }
     ).extend(cv.COMPONENT_SCHEMA),
     cv.has_at_least_one_key(CONF_TARGET_TEMPERATURE_DATAPOINT, CONF_SWITCH_DATAPOINT),
@@ -186,3 +188,6 @@ async def to_code(config):
         cg.add(var.set_eco_id(config[CONF_ECO_DATAPOINT]))
         if CONF_ECO_TEMPERATURE in config:
             cg.add(var.set_eco_temperature(config[CONF_ECO_TEMPERATURE]))
+
+    if config[CONF_REPORTS_FAHRENHEIT]:
+        cg.add(var.set_reports_fahrenheit())
